==> gromacs_2022.5.orig.tar.gz: gromacs-2022.5/src/gromacs/utility/gmxassert.cpp <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright 2011- The GROMACS Authors
 * and the project initiators Erik Lindahl, Berk Hess and David van der Spoel.
 * Consult the AUTHORS/COPYING files and https://www.gromacs.org for details.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * https://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at https://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out https://www.gromacs.org.
 */
/*! \internal \file
 * \brief
 * Implements assertion handlers.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \ingroup module_utility
 */
#include "gmxpre.h"

#include "gromacs/utility/gmxassert.h"

#include <cstdio>
#include <cstdlib>

#include "gromacs/utility/fatalerror.h"

#include "errorformat.h"

namespace gmx
{

/*! \cond internal */
namespace internal
{

void assertHandler(const char* condition, const char* msg, const char* func, const char* file, int line)
{
    printFatalErrorHeader(stderr, "Assertion failed", func, file, line);
    std::fprintf(stderr, "Condition: %s\n", condition);
    printFatalErrorMessageLine(stderr, msg, 0);
    printFatalErrorFooter(stderr);
    gmx_exit_on_fatal_error(ExitType_Abort, 1);
}

} // namespace internal
//! \endcond

} // namespace gmx

==> gromacs-2023.5.tar.gz: gromacs-2023.5/src/gromacs/utility/gmxassert.cpp <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright 2011- The GROMACS Authors
 * and the project initiators Erik Lindahl, Berk Hess and David van der Spoel.
 * Consult the AUTHORS/COPYING files and https://www.gromacs.org for details.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * https://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at https://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out https://www.gromacs.org.
 */
/*! \internal \file
 * \brief
 * Implements assertion handlers.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \ingroup module_utility
 */
#include "gmxpre.h"

#include "gromacs/utility/gmxassert.h"

#include <cstdio>
#include <cstdlib>

#include "gromacs/utility/fatalerror.h"

#include "errorformat.h"

namespace gmx
{

/*! \cond internal */
namespace internal
{

void assertHandler(const char* condition, const char* msg, const char* func, const std::filesystem::path& file, int line)
{
    printFatalErrorHeader(stderr, "Assertion failed", func, file, line);
    std::fprintf(stderr, "Condition: %s\n", condition);
    printFatalErrorMessageLine(stderr, msg, 0);
    printFatalErrorFooter(stderr);
    gmx_exit_on_fatal_error(ExitType_Abort, 1);
}

} // namespace internal
//! \endcond

} // namespace gmx
